@@ -14,6 +14,17 @@ NULL
 #' @import Rcpp
 NULL
 
+#' @importFrom stringr str_extract_all
+NULL
+#' @importFrom stringr str_replace_all
+NULL
+#' @importFrom stringr str_detect
+NULL
+
+#' @importFrom stats na.omit
+NULL
+#' @importFrom stats sd
+NULL
 #' @importFrom stats runif
 NULL
 #' @importFrom stats rnorm
@@ -30,6 +41,12 @@ NULL
 NULL
 #' @importFrom stats rexp
 NULL
+#' @importFrom stats printCoefmat
+NULL
+#' @importFrom stats model.frame
+NULL
+#' @importFrom stats model.matrix
+NULL
 
 #' @importFrom methods new
 #' @export
@@ -50,3 +67,9 @@ utils::read.table
 #' @importFrom utils write.table
 #' @export
 utils::write.table
+
+#' @exportS3Method summary blrMod
+NULL
+
+#' @exportS3Method print summary.blrMod
+NULL
